---
icon: material/comment-quote-outline
---

# Feedback

We highly value the insights of our users, and we would love to hear from you. If you are using Outlines for your projects and would like to share your experience with us, let's connect:

- What are you building with it?
- What do you like about it?
- What challenges are you facing?
- What do you think could be improved?

To schedule an appointment follow [this link](https://cal.com/dottxt/outlines). This is exclusively intended to share your experience, please go on [Discord](https://discord.gg/UppQmhEpe8) or [GitHub](https://github.com/outlines-dev/outlines/discussions) for support.
